﻿using Microsoft.AspNetCore.Mvc.RazorPages;

namespace DocuMed.Api.Controllers;

public class MedicalHistoryTemplateController : ICarterModule
{
    public virtual void AddRoutes(IEndpointRouteBuilder app)
    {
        var group = app.NewVersionedApi("MedicalHistoryTemplate").MapGroup($"api/medicalhistory/template")
            .RequireAuthorization(builder => builder.AddAuthenticationSchemes("Bearer").RequireAuthenticatedUser());

        group.MapGet("", GetAllAsync)
            .WithDisplayName("GetAll")
            .HasApiVersion(1.0);

        group.MapGet("{id}", GetAsync)
            .WithDisplayName("GetOne")
            .HasApiVersion(1.0);

        group.MapPost("", Post)
            .HasApiVersion(1.0);

        group.MapPut("", Put)
            .HasApiVersion(1.0);

        group.MapDelete("", Delete)
            .HasApiVersion(1.0);
    }


    // GET:Get All Entity
    public virtual async Task<IResult> GetAllAsync([FromQuery] int page, IMedicalHistoryTemplateRepository repository, CancellationToken cancellationToken)
    {
        return TypedResults.Ok(await repository.GetMedicalHistoryTemplatesAsync(page,cancellationToken));
    }

    // GET:Get An Entity By Id
    public async Task<IResult> GetAsync(Guid id, IMedicalHistoryTemplateRepository repository, CancellationToken cancellationToken)
    {
        
        return TypedResults.Ok(await repository.GetMedicalHistoryTemplateAsync(id, cancellationToken));
    }

    // POST:Add New Entity
    public virtual async Task<IResult> Post([FromBody] MedicalHistoryTemplateLDto dto, IMedicalHistoryTemplateService service, ICurrentUserService currentUserService, CancellationToken cancellationToken)
    {
        return TypedResults.Ok(await service.AddAsync(dto,cancellationToken));
    }

    // PUT:Update Entity
    public virtual async Task<IResult> Put([FromBody] MedicalHistoryTemplateLDto dto, IMedicalHistoryTemplateService service,ICurrentUserService currentUserService, CancellationToken cancellationToken)
    {
        return TypedResults.Ok(await service.EditAsync(dto, cancellationToken));
    }

    // DELETE:Delete Entity
    public virtual async Task<IResult> Delete(int id, IRepositoryWrapper repositoryWrapper, CancellationToken cancellationToken)
    {
        var ent = await repositoryWrapper.SetRepository<MedicalHistoryTemplate>().GetByIdAsync(cancellationToken, id);
        repositoryWrapper.SetRepository<MedicalHistoryTemplate>().Delete(ent);
        await repositoryWrapper.SaveChangesAsync(cancellationToken);
        return TypedResults.Ok();
    }
}