﻿namespace DocuMed.Repository.Repositories.Entities;

public class MedicalHistoryTemplateRepository : BaseRepository<MedicalHistoryTemplate>, IMedicalHistoryTemplateRepository 
{
    public MedicalHistoryTemplateRepository(ApplicationContext dbContext,ICurrentUserService currentUserService) : base(dbContext,currentUserService)
    {
    }

    public async Task<List<MedicalHistoryTemplateSDto>> GetMedicalHistoryTemplatesAsync(int page = 0, CancellationToken cancellationToken = default)
    {
        if (!Guid.TryParse(CurrentUserService.UserId, out Guid userId))
            throw new AppException("توکن غیرمجاز", ApiResultStatusCode.UnAuthorized);
        var list = await TableNoTracking
            .Where(t => t.ApplicationUserId == userId)
            .OrderByDescending(t => t.CreatedAt)
            .Skip(page * 15)
            .Take(15)
            .Select(MedicalHistoryTemplateMapper.ProjectToSDto)
            .ToListAsync(cancellationToken);
        return list;
    }

    public async Task<MedicalHistoryTemplateLDto> GetMedicalHistoryTemplateAsync(Guid id, CancellationToken cancellationToken = default)
    {
        var dto = await TableNoTracking.Where(t => t.Id == id)
            .Select(MedicalHistoryTemplateMapper.ProjectToLDto)
            .FirstOrDefaultAsync(cancellationToken);
        if (dto == null)
            throw new AppException("پیش نویس پیدا نشد", ApiResultStatusCode.NotFound);
        return dto;
    }
}